# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/fh-matui',
                'doc_host': 'https://abhisheksreesaila.github.io',
                'git_url': 'https://github.com/abhisheksreesaila/fh-matui',
                'lib_path': 'fh_matui'},
  'syms': { 'fh_matui.app_pages': { 'fh_matui.app_pages.LoginScreen': ('app_pages.html#loginscreen', 'fh_matui/app_pages.py'),
                                    'fh_matui.app_pages.TopContent': ('app_pages.html#topcontent', 'fh_matui/app_pages.py'),
                                    'fh_matui.app_pages.TopLayout': ('app_pages.html#toplayout', 'fh_matui/app_pages.py')},
            'fh_matui.components': { 'fh_matui.components.Abbr': ('components.html#abbr', 'fh_matui/components.py'),
                                     'fh_matui.components.Blockquote': ('components.html#blockquote', 'fh_matui/components.py'),
                                     'fh_matui.components.BottomNav': ('components.html#bottomnav', 'fh_matui/components.py'),
                                     'fh_matui.components.Card': ('components.html#card', 'fh_matui/components.py'),
                                     'fh_matui.components.CheckboxX': ('components.html#checkboxx', 'fh_matui/components.py'),
                                     'fh_matui.components.CodeBlock': ('components.html#codeblock', 'fh_matui/components.py'),
                                     'fh_matui.components.CodeSpan': ('components.html#codespan', 'fh_matui/components.py'),
                                     'fh_matui.components.ContainerT': ('components.html#containert', 'fh_matui/components.py'),
                                     'fh_matui.components.CookiesBanner': ('components.html#cookiesbanner', 'fh_matui/components.py'),
                                     'fh_matui.components.DivCentered': ('components.html#divcentered', 'fh_matui/components.py'),
                                     'fh_matui.components.DivFullySpaced': ('components.html#divfullyspaced', 'fh_matui/components.py'),
                                     'fh_matui.components.DivHStacked': ('components.html#divhstacked', 'fh_matui/components.py'),
                                     'fh_matui.components.DivLAligned': ('components.html#divlaligned', 'fh_matui/components.py'),
                                     'fh_matui.components.DivRAligned': ('components.html#divraligned', 'fh_matui/components.py'),
                                     'fh_matui.components.DivVStacked': ('components.html#divvstacked', 'fh_matui/components.py'),
                                     'fh_matui.components.Em': ('components.html#em', 'fh_matui/components.py'),
                                     'fh_matui.components.FAQItem': ('components.html#faqitem', 'fh_matui/components.py'),
                                     'fh_matui.components.Field': ('components.html#field', 'fh_matui/components.py'),
                                     'fh_matui.components.FormField': ('components.html#formfield', 'fh_matui/components.py'),
                                     'fh_matui.components.FormGrid': ('components.html#formgrid', 'fh_matui/components.py'),
                                     'fh_matui.components.FormLabel': ('components.html#formlabel', 'fh_matui/components.py'),
                                     'fh_matui.components.FormModal': ('components.html#formmodal', 'fh_matui/components.py'),
                                     'fh_matui.components.Grid': ('components.html#grid', 'fh_matui/components.py'),
                                     'fh_matui.components.GridCell': ('components.html#gridcell', 'fh_matui/components.py'),
                                     'fh_matui.components.GridSpanT': ('components.html#gridspant', 'fh_matui/components.py'),
                                     'fh_matui.components.Icon': ('components.html#icon', 'fh_matui/components.py'),
                                     'fh_matui.components.LabelInput': ('components.html#labelinput', 'fh_matui/components.py'),
                                     'fh_matui.components.Layout': ('components.html#layout', 'fh_matui/components.py'),
                                     'fh_matui.components.LoadingIndicator': ('components.html#loadingindicator', 'fh_matui/components.py'),
                                     'fh_matui.components.Mark': ('components.html#mark', 'fh_matui/components.py'),
                                     'fh_matui.components.Modal': ('components.html#modal', 'fh_matui/components.py'),
                                     'fh_matui.components.ModalBody': ('components.html#modalbody', 'fh_matui/components.py'),
                                     'fh_matui.components.ModalButton': ('components.html#modalbutton', 'fh_matui/components.py'),
                                     'fh_matui.components.ModalCancel': ('components.html#modalcancel', 'fh_matui/components.py'),
                                     'fh_matui.components.ModalConfirm': ('components.html#modalconfirm', 'fh_matui/components.py'),
                                     'fh_matui.components.ModalFooter': ('components.html#modalfooter', 'fh_matui/components.py'),
                                     'fh_matui.components.ModalTitle': ('components.html#modaltitle', 'fh_matui/components.py'),
                                     'fh_matui.components.NavBar': ('components.html#navbar', 'fh_matui/components.py'),
                                     'fh_matui.components.NavCloseLi': ('components.html#navcloseli', 'fh_matui/components.py'),
                                     'fh_matui.components.NavContainer': ('components.html#navcontainer', 'fh_matui/components.py'),
                                     'fh_matui.components.NavDividerLi': ('components.html#navdividerli', 'fh_matui/components.py'),
                                     'fh_matui.components.NavHeaderLi': ('components.html#navheaderli', 'fh_matui/components.py'),
                                     'fh_matui.components.NavSideBarContainer': ( 'components.html#navsidebarcontainer',
                                                                                  'fh_matui/components.py'),
                                     'fh_matui.components.NavSideBarHeader': ('components.html#navsidebarheader', 'fh_matui/components.py'),
                                     'fh_matui.components.NavSideBarLinks': ('components.html#navsidebarlinks', 'fh_matui/components.py'),
                                     'fh_matui.components.NavSubtitle': ('components.html#navsubtitle', 'fh_matui/components.py'),
                                     'fh_matui.components.NavToggleButton': ('components.html#navtogglebutton', 'fh_matui/components.py'),
                                     'fh_matui.components.Page': ('components.html#page', 'fh_matui/components.py'),
                                     'fh_matui.components.Pagination': ('components.html#pagination', 'fh_matui/components.py'),
                                     'fh_matui.components.Progress': ('components.html#progress', 'fh_matui/components.py'),
                                     'fh_matui.components.Q': ('components.html#q', 'fh_matui/components.py'),
                                     'fh_matui.components.Radio': ('components.html#radio', 'fh_matui/components.py'),
                                     'fh_matui.components.Range': ('components.html#range', 'fh_matui/components.py'),
                                     'fh_matui.components.Select': ('components.html#select', 'fh_matui/components.py'),
                                     'fh_matui.components.SelectMenu': ('components.html#selectmenu', 'fh_matui/components.py'),
                                     'fh_matui.components.Small': ('components.html#small', 'fh_matui/components.py'),
                                     'fh_matui.components.Snackbar': ('components.html#snackbar', 'fh_matui/components.py'),
                                     'fh_matui.components.SpaceT': ('components.html#spacet', 'fh_matui/components.py'),
                                     'fh_matui.components.Strong': ('components.html#strong', 'fh_matui/components.py'),
                                     'fh_matui.components.Sub': ('components.html#sub', 'fh_matui/components.py'),
                                     'fh_matui.components.Sup': ('components.html#sup', 'fh_matui/components.py'),
                                     'fh_matui.components.Switch': ('components.html#switch', 'fh_matui/components.py'),
                                     'fh_matui.components.Table': ('components.html#table', 'fh_matui/components.py'),
                                     'fh_matui.components.TableControls': ('components.html#tablecontrols', 'fh_matui/components.py'),
                                     'fh_matui.components.TableFromDicts': ('components.html#tablefromdicts', 'fh_matui/components.py'),
                                     'fh_matui.components.TableFromLists': ('components.html#tablefromlists', 'fh_matui/components.py'),
                                     'fh_matui.components.Tbody': ('components.html#tbody', 'fh_matui/components.py'),
                                     'fh_matui.components.Td': ('components.html#td', 'fh_matui/components.py'),
                                     'fh_matui.components.TextArea': ('components.html#textarea', 'fh_matui/components.py'),
                                     'fh_matui.components.TextPresets': ('components.html#textpresets', 'fh_matui/components.py'),
                                     'fh_matui.components.TextT': ('components.html#textt', 'fh_matui/components.py'),
                                     'fh_matui.components.Tfoot': ('components.html#tfoot', 'fh_matui/components.py'),
                                     'fh_matui.components.Th': ('components.html#th', 'fh_matui/components.py'),
                                     'fh_matui.components.Thead': ('components.html#thead', 'fh_matui/components.py'),
                                     'fh_matui.components.Toast': ('components.html#toast', 'fh_matui/components.py'),
                                     'fh_matui.components.Toolbar': ('components.html#toolbar', 'fh_matui/components.py'),
                                     'fh_matui.components._AnchorChain': ('components.html#_anchorchain', 'fh_matui/components.py'),
                                     'fh_matui.components._ButtonChain': ('components.html#_buttonchain', 'fh_matui/components.py'),
                                     'fh_matui.components._get_form_config': ('components.html#_get_form_config', 'fh_matui/components.py'),
                                     'fh_matui.components._has_space_token': ('components.html#_has_space_token', 'fh_matui/components.py'),
                                     'fh_matui.components._make_anchor_property': ( 'components.html#_make_anchor_property',
                                                                                    'fh_matui/components.py'),
                                     'fh_matui.components._make_button_property': ( 'components.html#_make_button_property',
                                                                                    'fh_matui/components.py'),
                                     'fh_matui.components._snap_to_valid_cols': ( 'components.html#_snap_to_valid_cols',
                                                                                  'fh_matui/components.py'),
                                     'fh_matui.components._wrap_grid_children': ( 'components.html#_wrap_grid_children',
                                                                                  'fh_matui/components.py')},
            'fh_matui.core': { 'fh_matui.core.BeerCssChain': ('core.html#beercsschain', 'fh_matui/core.py'),
                               'fh_matui.core.BeerCssChain.__init__': ('core.html#beercsschain.__init__', 'fh_matui/core.py'),
                               'fh_matui.core.BeerCssChain.__iter__': ('core.html#beercsschain.__iter__', 'fh_matui/core.py'),
                               'fh_matui.core.BeerCssChain.__repr__': ('core.html#beercsschain.__repr__', 'fh_matui/core.py'),
                               'fh_matui.core.BeerCssChain.__str__': ('core.html#beercsschain.__str__', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeChain': ('core.html#_themechain', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeChain.__init__': ('core.html#_themechain.__init__', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeChain.headers': ('core.html#_themechain.headers', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace': ('core.html#_themenamespace', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.amber': ('core.html#_themenamespace.amber', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.blue': ('core.html#_themenamespace.blue', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.blue_grey': ('core.html#_themenamespace.blue_grey', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.brown': ('core.html#_themenamespace.brown', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.cyan': ('core.html#_themenamespace.cyan', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.deep_orange': ('core.html#_themenamespace.deep_orange', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.deep_purple': ('core.html#_themenamespace.deep_purple', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.gray': ('core.html#_themenamespace.gray', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.green': ('core.html#_themenamespace.green', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.grey': ('core.html#_themenamespace.grey', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.indigo': ('core.html#_themenamespace.indigo', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.light_blue': ('core.html#_themenamespace.light_blue', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.light_green': ('core.html#_themenamespace.light_green', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.lime': ('core.html#_themenamespace.lime', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.neutral': ('core.html#_themenamespace.neutral', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.orange': ('core.html#_themenamespace.orange', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.pink': ('core.html#_themenamespace.pink', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.purple': ('core.html#_themenamespace.purple', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.red': ('core.html#_themenamespace.red', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.rose': ('core.html#_themenamespace.rose', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.slate': ('core.html#_themenamespace.slate', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.stone': ('core.html#_themenamespace.stone', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.teal': ('core.html#_themenamespace.teal', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.violet': ('core.html#_themenamespace.violet', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.yellow': ('core.html#_themenamespace.yellow', 'fh_matui/core.py'),
                               'fh_matui.core._ThemeNamespace.zinc': ('core.html#_themenamespace.zinc', 'fh_matui/core.py')},
            'fh_matui.datatable': { 'fh_matui.datatable.CrudContext': ('datatable.html#crudcontext', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTable': ('datatable.html#datatable', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource': ('datatable.html#datatableresource', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource.__init__': ( 'datatable.html#datatableresource.__init__',
                                                                                       'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._build_context': ( 'datatable.html#datatableresource._build_context',
                                                                                             'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._call_hook': ( 'datatable.html#datatableresource._call_hook',
                                                                                         'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._error_toast': ( 'datatable.html#datatableresource._error_toast',
                                                                                           'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._filter_by_search': ( 'datatable.html#datatableresource._filter_by_search',
                                                                                                'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._get_filtered_data': ( 'datatable.html#datatableresource._get_filtered_data',
                                                                                                 'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._handle_action': ( 'datatable.html#datatableresource._handle_action',
                                                                                             'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._handle_save': ( 'datatable.html#datatableresource._handle_save',
                                                                                           'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._handle_table': ( 'datatable.html#datatableresource._handle_table',
                                                                                            'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._paginate': ( 'datatable.html#datatableresource._paginate',
                                                                                        'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._register_routes': ( 'datatable.html#datatableresource._register_routes',
                                                                                               'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._success_toast': ( 'datatable.html#datatableresource._success_toast',
                                                                                             'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._wrap_modal': ( 'datatable.html#datatableresource._wrap_modal',
                                                                                          'fh_matui/datatable.py'),
                                    'fh_matui.datatable.DataTableResource._wrap_response': ( 'datatable.html#datatableresource._wrap_response',
                                                                                             'fh_matui/datatable.py'),
                                    'fh_matui.datatable._action_menu': ('datatable.html#_action_menu', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable._group_data': ('datatable.html#_group_data', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable._is_htmx_request': ('datatable.html#_is_htmx_request', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable._page_size_select': ('datatable.html#_page_size_select', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable._safe_int': ('datatable.html#_safe_int', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable._to_dict': ('datatable.html#_to_dict', 'fh_matui/datatable.py'),
                                    'fh_matui.datatable.table_state_from_request': ( 'datatable.html#table_state_from_request',
                                                                                     'fh_matui/datatable.py')},
            'fh_matui.foundations': { 'fh_matui.foundations.VEnum': ('foundations.html#venum', 'fh_matui/foundations.py'),
                                      'fh_matui.foundations.VEnum.__add__': ('foundations.html#venum.__add__', 'fh_matui/foundations.py'),
                                      'fh_matui.foundations.VEnum.__radd__': ('foundations.html#venum.__radd__', 'fh_matui/foundations.py'),
                                      'fh_matui.foundations.VEnum.__str__': ('foundations.html#venum.__str__', 'fh_matui/foundations.py'),
                                      'fh_matui.foundations.dedupe_preserve_order': ( 'foundations.html#dedupe_preserve_order',
                                                                                      'fh_matui/foundations.py'),
                                      'fh_matui.foundations.normalize_tokens': ( 'foundations.html#normalize_tokens',
                                                                                 'fh_matui/foundations.py'),
                                      'fh_matui.foundations.stringify': ('foundations.html#stringify', 'fh_matui/foundations.py')},
            'fh_matui.web_pages': { 'fh_matui.web_pages.ContentPage': ('web_pages.html#contentpage', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.FAQSection': ('web_pages.html#faqsection', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.FeatureShowcase': ('web_pages.html#featureshowcase', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.FeaturesGrid': ('web_pages.html#featuresgrid', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.HeroSection': ('web_pages.html#herosection', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.LandingNavBar': ('web_pages.html#landingnavbar', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.LandingPageSimple': ('web_pages.html#landingpagesimple', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.MarkdownSection': ('web_pages.html#markdownsection', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.PageFooter': ('web_pages.html#pagefooter', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages.PricingSection': ('web_pages.html#pricingsection', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages._SectionWave': ('web_pages.html#_sectionwave', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages._calc_savings_pct': ('web_pages.html#_calc_savings_pct', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages._pricing_card': ('web_pages.html#_pricing_card', 'fh_matui/web_pages.py'),
                                    'fh_matui.web_pages._pricing_toggle_js': ( 'web_pages.html#_pricing_toggle_js',
                                                                               'fh_matui/web_pages.py')}}}
